@@ -1,6 +1,7 @@
 import deskbar.interfaces.Action
 from gettext import gettext as _
 from deskbar.core.Utils import url_show
+import cgi
 
 class ShowUrlAction(deskbar.interfaces.Action):
     """
@@ -24,4 +25,7 @@ class ShowUrlAction(deskbar.interfaces.Action):
         return _("Open %s") % "<b>%(name)s</b>" 
     
     def activate(self, text=None):
-        url_show(self._url)
\ No newline at end of file
+        url_show(self._url)
+        
+    def get_tooltip(self, text=None):
+        return cgi.escape(self._url)
\ No newline at end of file
